@@ -50,6 +50,10 @@
 HD_DEFINE_TYPE_MODULE_EXTENDED (TN, t_n, T_P, 0, {})	\
 HILDON_DESKTOP_PLUGIN_SYMBOLS (t_n)
 
+#define HD_DEFINE_PLUGIN_WITH_CODE(TN, t_n, T_P, CODE)  \
+HD_DEFINE_TYPE_MODULE_EXTENDED (TN, t_n, T_P, 0, CODE)	\
+HILDON_DESKTOP_PLUGIN_SYMBOLS (t_n)
+
 #define HD_DEFINE_TYPE_MODULE_EXTENDED(TypeName, type_name, TYPE_PARENT, flags, CODE)	\
 											\
 static GType    type_name##_type_id = 0;                                              	\
@@ -95,7 +99,7 @@ type_name##_register_type (GTypeModule *module) 					\
                                      #TypeName, 					\
                                      &g_define_type_info, 				\
                                      (GTypeFlags) flags); 				\
-    { CODE ; } 										\
+    { CODE } 										\
   } 											\
 											\
   return type_name##_type_id; 								\
